@@ -1,3 +1,11 @@
+"""
+Module with all decorators that are exposed for users.
+
+Currently only:
+* property_field - exposing @property like function as field in Model.dict()
+* predefined signals decorators (pre/post + save/update/delete)
+
+"""
 from ormar.decorators.property_field import property_field
 from ormar.decorators.signals import (
     post_delete,
